@@ -158,7 +158,9 @@ class Solver:
             new_packages = self._solve()
             override_packages.append((override, new_packages))
 
-        return merge_override_packages(override_packages)
+        return merge_override_packages(
+            override_packages, self._package.python_constraint
+        )
 
     def _solve(self) -> dict[Package, TransitivePackageInfo]:
         if self._provider._overrides:
@@ -297,7 +299,7 @@ class PackageNode(DFSNode):
         self.depth = -1
 
         if not previous:
-            self.groups: frozenset[str] = frozenset()
+            self.groups: frozenset[NormalizedName] = frozenset()
             self.optional = True
         elif dep:
             self.groups = dep.groups
@@ -359,7 +361,7 @@ def aggregate_package_nodes(
 ) -> tuple[Package, TransitivePackageInfo]:
     package = nodes[0].package
     depth = max(node.depth for node in nodes)
-    groups: set[str] = set()
+    groups: set[NormalizedName] = set()
     for node in nodes:
         groups.update(node.groups)
 
@@ -393,7 +395,7 @@ def calculate_markers(
         for depth in range(max_depth + 1):
             for package in packages_by_depth[depth]:
                 transitive_info = packages[package]
-                transitive_marker: dict[str, BaseMarker] = {
+                transitive_marker: dict[NormalizedName, BaseMarker] = {
                     group: EmptyMarker() for group in transitive_info.groups
                 }
                 for parent, m in markers[package].items():
@@ -419,6 +421,7 @@ def merge_override_packages(
             dict[Package, dict[str, Dependency]], dict[Package, TransitivePackageInfo]
         ]
     ],
+    python_constraint: VersionConstraint,
 ) -> dict[Package, TransitivePackageInfo]:
     result: dict[Package, TransitivePackageInfo] = {}
     all_packages: dict[
@@ -429,6 +432,7 @@ def merge_override_packages(
         for deps in override.values():
             for dep in deps.values():
                 override_marker = override_marker.intersect(dep.marker.without_extras())
+        override_marker = simplify_marker(override_marker, python_constraint)
         for package, info in o_packages.items():
             for group, marker in info.markers.items():
                 # `override_marker` is often a SingleMarker or a MultiMarker,
