@@ -1,18 +1,16 @@
 from __future__ import annotations
 
+import locale
 import sys
 
 from contextlib import suppress
 
 
-# TODO: use try/except ImportError when
-# https://github.com/python/mypy/issues/1393 is fixed
-
 if sys.version_info < (3, 11):
     # compatibility for python <3.11
     import tomli as tomllib
 else:
-    import tomllib  # nopycln: import
+    import tomllib
 
 
 if sys.version_info < (3, 10):
@@ -21,12 +19,6 @@ if sys.version_info < (3, 10):
 else:
     from importlib import metadata
 
-if sys.version_info < (3, 8):
-    # compatibility for python <3.8
-    from backports.cached_property import cached_property
-else:
-    from functools import cached_property
-
 WINDOWS = sys.platform == "win32"
 
 
@@ -56,24 +48,18 @@ def encode(string: str, encodings: list[str] | None = None) -> bytes:
     return string.encode(encodings[0], errors="ignore")
 
 
-def to_str(string: str) -> str:
-    return decode(string)
-
-
-def list_to_shell_command(cmd: list[str]) -> str:
-    return " ".join(
-        f'"{token}"' if " " in token and token[0] not in {"'", '"'} else token
-        for token in cmd
-    )
+def getencoding() -> str:
+    if sys.version_info < (3, 11):
+        return locale.getpreferredencoding()
+    else:
+        return locale.getencoding()
 
 
 __all__ = [
     "WINDOWS",
-    "cached_property",
     "decode",
     "encode",
-    "list_to_shell_command",
+    "getencoding",
     "metadata",
-    "to_str",
     "tomllib",
 ]
