@@ -5,17 +5,21 @@ import hashlib
 import json
 import logging
 import shutil
+import threading
 import time
 
+from collections import defaultdict
 from pathlib import Path
 from typing import TYPE_CHECKING
 from typing import Any
 from typing import Generic
 from typing import TypeVar
+from typing import overload
 
 from poetry.utils._compat import decode
 from poetry.utils._compat import encode
-from poetry.utils.wheel import InvalidWheelName
+from poetry.utils.helpers import get_highest_priority_hash_type
+from poetry.utils.wheel import InvalidWheelNameError
 from poetry.utils.wheel import Wheel
 
 
@@ -187,12 +191,15 @@ class FileCache(Generic[T]):
 class ArtifactCache:
     def __init__(self, *, cache_dir: Path) -> None:
         self._cache_dir = cache_dir
+        self._archive_locks: defaultdict[Path, threading.Lock] = defaultdict(
+            threading.Lock
+        )
 
     def get_cache_directory_for_link(self, link: Link) -> Path:
         key_parts = {"url": link.url_without_fragment}
 
-        if link.hash_name is not None and link.hash is not None:
-            key_parts[link.hash_name] = link.hash
+        if hash_name := get_highest_priority_hash_type(link.hashes, link.filename):
+            key_parts[hash_name] = link.hashes[hash_name]
 
         if link.subdirectory_fragment:
             key_parts["subdirectory"] = link.subdirectory_fragment
@@ -218,18 +225,54 @@ class ArtifactCache:
 
         return self._get_directory_from_hash(key_parts)
 
+    @overload
+    def get_cached_archive_for_link(
+        self,
+        link: Link,
+        *,
+        strict: bool,
+        env: Env | None = ...,
+        download_func: Callable[[str, Path], None],
+    ) -> Path: ...
+
+    @overload
+    def get_cached_archive_for_link(
+        self,
+        link: Link,
+        *,
+        strict: bool,
+        env: Env | None = ...,
+        download_func: None = ...,
+    ) -> Path | None: ...
+
     def get_cached_archive_for_link(
         self,
         link: Link,
         *,
         strict: bool,
         env: Env | None = None,
+        download_func: Callable[[str, Path], None] | None = None,
     ) -> Path | None:
         cache_dir = self.get_cache_directory_for_link(link)
 
-        return self._get_cached_archive(
+        cached_archive = self._get_cached_archive(
             cache_dir, strict=strict, filename=link.filename, env=env
         )
+        if cached_archive is None and strict and download_func is not None:
+            cached_archive = cache_dir / link.filename
+            with self._archive_locks[cached_archive]:
+                # Check again if the archive exists (under the lock) to avoid
+                # duplicate downloads because it may have already been downloaded
+                # by another thread in the meantime
+                if not cached_archive.exists():
+                    cache_dir.mkdir(parents=True, exist_ok=True)
+                    try:
+                        download_func(link.url, cached_archive)
+                    except BaseException:
+                        cached_archive.unlink(missing_ok=True)
+                        raise
+
+        return cached_archive
 
     def get_cached_archive_for_git(
         self, url: str, reference: str, subdirectory: str | None, env: Env
@@ -246,8 +289,9 @@ class ArtifactCache:
         filename: str | None = None,
         env: Env | None = None,
     ) -> Path | None:
+        # implication "not strict -> env must not be None"
         assert strict or env is not None
-        # implication "strict -> filename should not be None"
+        # implication "strict -> filename must not be None"
         assert not strict or filename is not None
 
         archives = self._get_cached_archives(cache_dir)
@@ -272,7 +316,7 @@ class ArtifactCache:
 
             try:
                 wheel = Wheel(archive.name)
-            except InvalidWheelName:
+            except InvalidWheelNameError:
                 continue
 
             if not wheel.is_supported_by_environment(env):
