@@ -10,8 +10,6 @@ from tests.helpers import get_package
 
 
 if TYPE_CHECKING:
-    import httpretty
-
     from cleo.testers.command_tester import CommandTester
 
     from poetry.poetry import Poetry
@@ -89,61 +87,7 @@ def poetry_with_invalid_lockfile(
     return _project_factory("invalid_lock", project_factory, fixture_dir)
 
 
-def test_lock_check_outdated_legacy(
-    command_tester_factory: CommandTesterFactory,
-    poetry_with_outdated_lockfile: Poetry,
-    http: type[httpretty.httpretty],
-) -> None:
-    http.disable()
-
-    locker = Locker(
-        lock=poetry_with_outdated_lockfile.pyproject.file.path.parent / "poetry.lock",
-        local_config=poetry_with_outdated_lockfile.locker._local_config,
-    )
-    poetry_with_outdated_lockfile.set_locker(locker)
-
-    tester = command_tester_factory("lock", poetry=poetry_with_outdated_lockfile)
-    status_code = tester.execute("--check")
-    expected = (
-        "poetry lock --check is deprecated, use `poetry check --lock` instead.\n"
-        "Error: poetry.lock is not consistent with pyproject.toml. "
-        "Run `poetry lock [--no-update]` to fix it.\n"
-    )
-
-    assert tester.io.fetch_error() == expected
-
-    # exit with an error
-    assert status_code == 1
-
-
-def test_lock_check_up_to_date_legacy(
-    command_tester_factory: CommandTesterFactory,
-    poetry_with_up_to_date_lockfile: Poetry,
-    http: type[httpretty.httpretty],
-) -> None:
-    http.disable()
-
-    locker = Locker(
-        lock=poetry_with_up_to_date_lockfile.pyproject.file.path.parent / "poetry.lock",
-        local_config=poetry_with_up_to_date_lockfile.locker._local_config,
-    )
-    poetry_with_up_to_date_lockfile.set_locker(locker)
-
-    tester = command_tester_factory("lock", poetry=poetry_with_up_to_date_lockfile)
-    status_code = tester.execute("--check")
-    expected = "poetry.lock is consistent with pyproject.toml.\n"
-    assert tester.io.fetch_output() == expected
-
-    expected_error = (
-        "poetry lock --check is deprecated, use `poetry check --lock` instead.\n"
-    )
-    assert tester.io.fetch_error() == expected_error
-
-    # exit with an error
-    assert status_code == 0
-
-
-def test_lock_no_update(
+def test_lock_does_not_update_if_not_necessary(
     command_tester_factory: CommandTesterFactory,
     poetry_with_old_lockfile: Poetry,
     repo: TestRepository,
@@ -153,7 +97,7 @@ def test_lock_no_update(
 
     locker = Locker(
         lock=poetry_with_old_lockfile.pyproject.file.path.parent / "poetry.lock",
-        local_config=poetry_with_old_lockfile.locker._local_config,
+        pyproject_data=poetry_with_old_lockfile.locker._pyproject_data,
     )
     poetry_with_old_lockfile.set_locker(locker)
 
@@ -164,26 +108,28 @@ def test_lock_no_update(
     )
 
     tester = command_tester_factory("lock", poetry=poetry_with_old_lockfile)
-    tester.execute("--no-update")
+    tester.execute()
 
     locker = Locker(
         lock=poetry_with_old_lockfile.pyproject.file.path.parent / "poetry.lock",
-        local_config={},
+        pyproject_data={},
     )
     packages = locker.locked_repository().packages
 
     assert len(packages) == len(locked_repository.packages)
 
-    assert locker.lock_data["metadata"].get("lock-version") == "2.0"
+    assert locker.lock_data["metadata"].get("lock-version") == "2.1"
 
     for package in packages:
         assert locked_repository.find_packages(package.to_dependency())
 
 
-def test_lock_no_update_path_dependencies(
+@pytest.mark.parametrize("regenerate", [True, False])
+def test_lock_always_updates_path_dependencies(
     command_tester_factory: CommandTesterFactory,
     poetry_with_nested_path_deps_old_lockfile: Poetry,
     repo: TestRepository,
+    regenerate: bool,
 ) -> None:
     """
     The lock file contains a variant of the directory dependency "quix" that does
@@ -196,21 +142,21 @@ def test_lock_no_update_path_dependencies(
     locker = Locker(
         lock=poetry_with_nested_path_deps_old_lockfile.pyproject.file.path.parent
         / "poetry.lock",
-        local_config=poetry_with_nested_path_deps_old_lockfile.locker._local_config,
+        pyproject_data=poetry_with_nested_path_deps_old_lockfile.locker._pyproject_data,
     )
     poetry_with_nested_path_deps_old_lockfile.set_locker(locker)
 
     tester = command_tester_factory(
         "lock", poetry=poetry_with_nested_path_deps_old_lockfile
     )
-    tester.execute("--no-update")
+    tester.execute("--regenerate" if regenerate else "")
 
     packages = locker.locked_repository().packages
 
     assert {p.name for p in packages} == {"quix", "sampleproject"}
 
 
-@pytest.mark.parametrize("update", [True, False])
+@pytest.mark.parametrize("regenerate", [True, False])
 @pytest.mark.parametrize(
     "project", ["missing_directory_dependency", "missing_file_dependency"]
 )
@@ -219,18 +165,18 @@ def test_lock_path_dependency_does_not_exist(
     project_factory: ProjectFactory,
     fixture_dir: FixtureDirGetter,
     project: str,
-    update: bool,
+    regenerate: bool,
 ) -> None:
     poetry = _project_factory(project, project_factory, fixture_dir)
     locker = Locker(
         lock=poetry.pyproject.file.path.parent / "poetry.lock",
-        local_config=poetry.locker._local_config,
+        pyproject_data=poetry.locker._pyproject_data,
     )
     poetry.set_locker(locker)
-    options = "" if update else "--no-update"
+    options = "--regenerate" if regenerate else ""
 
     tester = command_tester_factory("lock", poetry=poetry)
-    if update or "directory" in project:
+    if regenerate or "directory" in project:
         # directory dependencies are always updated
         with pytest.raises(ValueError, match="does not exist"):
             tester.execute(options)
@@ -238,7 +184,7 @@ def test_lock_path_dependency_does_not_exist(
         tester.execute(options)
 
 
-@pytest.mark.parametrize("update", [True, False])
+@pytest.mark.parametrize("regenerate", [True, False])
 @pytest.mark.parametrize(
     "project", ["deleted_directory_dependency", "deleted_file_dependency"]
 )
@@ -247,78 +193,75 @@ def test_lock_path_dependency_deleted_from_pyproject(
     project_factory: ProjectFactory,
     fixture_dir: FixtureDirGetter,
     project: str,
-    update: bool,
+    regenerate: bool,
 ) -> None:
     poetry = _project_factory(project, project_factory, fixture_dir)
     locker = Locker(
         lock=poetry.pyproject.file.path.parent / "poetry.lock",
-        local_config=poetry.locker._local_config,
+        pyproject_data=poetry.locker._pyproject_data,
     )
     poetry.set_locker(locker)
 
     tester = command_tester_factory("lock", poetry=poetry)
-    if update:
-        tester.execute("")
-    else:
-        tester.execute("--no-update")
+    tester.execute("--regenerate" if regenerate else "")
 
     packages = locker.locked_repository().packages
 
     assert {p.name for p in packages} == set()
 
 
-@pytest.mark.parametrize("is_no_update", [False, True])
+@pytest.mark.parametrize("regenerate", [True, False])
 def test_lock_with_incompatible_lockfile(
     command_tester_factory: CommandTesterFactory,
     poetry_with_incompatible_lockfile: Poetry,
     repo: TestRepository,
-    is_no_update: bool,
+    regenerate: bool,
 ) -> None:
     repo.add_package(get_package("sampleproject", "1.3.1"))
 
     locker = Locker(
         lock=poetry_with_incompatible_lockfile.pyproject.file.path.parent
         / "poetry.lock",
-        local_config=poetry_with_incompatible_lockfile.locker._local_config,
+        pyproject_data=poetry_with_incompatible_lockfile.locker._pyproject_data,
     )
     poetry_with_incompatible_lockfile.set_locker(locker)
 
     tester = command_tester_factory("lock", poetry=poetry_with_incompatible_lockfile)
-    if is_no_update:
+    if regenerate:
+        # still possible because lock file is not required
+        status_code = tester.execute("--regenerate")
+        assert status_code == 0
+    else:
         # not possible because of incompatible lock file
         expected = (
             "(?s)lock file is not compatible .*"
             " regenerate the lock file with the `poetry lock` command"
         )
         with pytest.raises(RuntimeError, match=expected):
-            tester.execute("--no-update")
-    else:
-        # still possible because lock file is not required
-        status_code = tester.execute()
-        assert status_code == 0
+            tester.execute()
 
 
-@pytest.mark.parametrize("is_no_update", [False, True])
+@pytest.mark.parametrize("regenerate", [True, False])
 def test_lock_with_invalid_lockfile(
     command_tester_factory: CommandTesterFactory,
     poetry_with_invalid_lockfile: Poetry,
     repo: TestRepository,
-    is_no_update: bool,
+    regenerate: bool,
 ) -> None:
     repo.add_package(get_package("sampleproject", "1.3.1"))
 
     locker = Locker(
         lock=poetry_with_invalid_lockfile.pyproject.file.path.parent / "poetry.lock",
-        local_config=poetry_with_invalid_lockfile.locker._local_config,
+        pyproject_data=poetry_with_invalid_lockfile.locker._pyproject_data,
     )
     poetry_with_invalid_lockfile.set_locker(locker)
 
     tester = command_tester_factory("lock", poetry=poetry_with_invalid_lockfile)
-    if is_no_update:
+    if regenerate:
+        # still possible because lock file is not required
+        status_code = tester.execute("--regenerate")
+        assert status_code == 0
+    else:
         # not possible because of broken lock file
         with pytest.raises(RuntimeError, match="Unable to read the lock file"):
-            tester.execute("--no-update")
-    else:
-        # still possible because lock file is not required
-        status_code = tester.execute()
-        assert status_code == 0
+            tester.execute()
