@@ -129,7 +129,87 @@ bar = "^1.0.0"
     assert expected_poetry_string in string_content
 
 
+def test_remove_from_pep735_group_and_poetry_group(
+    tester: CommandTester,
+    app: PoetryTestApplication,
+    repo: TestRepository,
+    installed: Repository,
+) -> None:
+    repo.add_package(Package("foo", "2.0.0"))
+    repo.add_package(Package("bar", "1.0.0"))
+
+    pyproject: dict[str, Any] = app.poetry.file.read()
+
+    pep735_dependencies: dict[str, Any] = tomlkit.parse(
+        """\
+[dependency-groups]
+dev = [
+    "foo>=2.0",
+    "bar>=1.0",
+]
+"""
+    )
+
+    poetry_dependencies: dict[str, Any] = tomlkit.parse(
+        """\
+[tool.poetry.group.dev.dependencies]
+foo = "^2.0.0"
+bar = "^1.0.0"
+
+"""
+    )
+
+    pyproject["dependency-groups"] = pep735_dependencies["dependency-groups"]
+    pyproject["tool"]["poetry"]["group"] = poetry_dependencies["tool"]["poetry"][
+        "group"
+    ]
+    pyproject = cast("TOMLDocument", pyproject)
+    app.poetry.file.write(pyproject)
+
+    app.poetry.package.add_dependency(
+        Factory.create_dependency("foo", "^2.0.0", groups=["dev"])
+    )
+    app.poetry.package.add_dependency(
+        Factory.create_dependency("bar", "^1.0.0", groups=["dev"])
+    )
+
+    tester.execute("foo")
+
+    pyproject = app.poetry.file.read()
+    pyproject = cast("dict[str, Any]", pyproject)
+    pep735_dependencies = pyproject["dependency-groups"]["dev"]
+    assert "foo>=2.0" not in pep735_dependencies
+    assert "bar>=1.0" in pep735_dependencies
+    poetry_dependencies = pyproject["tool"]["poetry"]["group"]["dev"]["dependencies"]
+    assert "foo" not in poetry_dependencies
+    assert "bar" in poetry_dependencies
+
+    expected_pep735_string = """\
+[dependency-groups]
+dev = [
+    "bar>=1.0",
+]
+"""
+    expected_poetry_string = """\
+
+[tool.poetry.group.dev.dependencies]
+bar = "^1.0.0"
+
+"""
+    pyproject = cast("TOMLDocument", pyproject)
+    string_content = pyproject.as_string()
+    if "\r\n" in string_content:
+        # consistent line endings
+        expected_pep735_string = expected_pep735_string.replace("\n", "\r\n")
+        expected_poetry_string = expected_poetry_string.replace("\n", "\r\n")
+
+    assert expected_pep735_string in string_content
+    assert expected_poetry_string in string_content
+
+
+@pytest.mark.parametrize("pep_735", [True, False])
 def test_remove_without_specific_group_removes_from_all_groups(
+    pep_735: bool,
     tester: CommandTester,
     app: PoetryTestApplication,
     repo: TestRepository,
@@ -143,17 +223,32 @@ def test_remove_without_specific_group_removes_from_all_groups(
     repo.add_package(Package("baz", "1.0.0"))
 
     pyproject: dict[str, Any] = app.poetry.file.read()
+    pyproject["tool"]["poetry"]["dependencies"]["foo"] = "^2.0.0"
 
-    groups_content: dict[str, Any] = tomlkit.parse(
-        """\
+    if pep_735:
+        groups_content: dict[str, Any] = tomlkit.parse(
+            """\
+[dependency-groups]
+bar = [
+    "foo (>=2.0,<3.0)",
+    "baz (>=1.0,<2.0)",
+]
+"""
+        )
+        pyproject["dependency-groups"] = groups_content["dependency-groups"]
+
+    else:
+        groups_content = tomlkit.parse(
+            """\
 [tool.poetry.group.bar.dependencies]
 foo = "^2.0.0"
 baz = "^1.0.0"
 
 """
-    )
-    pyproject["tool"]["poetry"]["dependencies"]["foo"] = "^2.0.0"
-    pyproject["tool"]["poetry"]["group"] = groups_content["tool"]["poetry"]["group"]
+        )
+        groups_content = cast("dict[str, Any]", groups_content)
+        pyproject["tool"]["poetry"]["group"] = groups_content["tool"]["poetry"]["group"]
+
     pyproject = cast("TOMLDocument", pyproject)
     app.poetry.file.write(pyproject)
 
@@ -171,14 +266,23 @@ baz = "^1.0.0"
     pyproject = cast("dict[str, Any]", pyproject)
     content = pyproject["tool"]["poetry"]
     assert "foo" not in content["dependencies"]
-    assert "foo" not in content["group"]["bar"]["dependencies"]
-    assert "baz" in content["group"]["bar"]["dependencies"]
 
-    expected = """\
+    if pep_735:
+        assert not any("foo" in dep for dep in pyproject["dependency-groups"]["bar"])
+        assert any("baz" in dep for dep in pyproject["dependency-groups"]["bar"])
+        expected = """\
+[dependency-groups]
+bar = [
+    "baz (>=1.0,<2.0)",
+]
+"""
+    else:
+        assert "foo" not in content["group"]["bar"]["dependencies"]
+        assert "baz" in content["group"]["bar"]["dependencies"]
 
+        expected = """\
 [tool.poetry.group.bar.dependencies]
 baz = "^1.0.0"
-
 """
     pyproject = cast("TOMLDocument", pyproject)
     string_content = pyproject.as_string()
@@ -189,7 +293,9 @@ baz = "^1.0.0"
     assert expected in string_content
 
 
+@pytest.mark.parametrize("pep_735", [True, False])
 def test_remove_with_specific_group_removes_from_specific_groups(
+    pep_735: bool,
     tester: CommandTester,
     app: PoetryTestApplication,
     repo: TestRepository,
@@ -203,17 +309,31 @@ def test_remove_with_specific_group_removes_from_specific_groups(
     repo.add_package(Package("baz", "1.0.0"))
 
     pyproject: dict[str, Any] = app.poetry.file.read()
+    pyproject["tool"]["poetry"]["dependencies"]["foo"] = "^2.0.0"
 
-    groups_content: dict[str, Any] = tomlkit.parse(
-        """\
+    if pep_735:
+        groups_content: dict[str, Any] = tomlkit.parse(
+            """\
+[dependency-groups]
+bar = [
+    "foo (>=2.0,<3.0)",
+    "baz (>=1.0,<2.0)",
+]
+    """
+        )
+        pyproject["dependency-groups"] = groups_content["dependency-groups"]
+
+    else:
+        groups_content = tomlkit.parse(
+            """\
 [tool.poetry.group.bar.dependencies]
 foo = "^2.0.0"
 baz = "^1.0.0"
+    """
+        )
+        groups_content = cast("dict[str, Any]", groups_content)
+        pyproject["tool"]["poetry"]["group"] = groups_content["tool"]["poetry"]["group"]
 
-"""
-    )
-    pyproject["tool"]["poetry"]["dependencies"]["foo"] = "^2.0.0"
-    pyproject["tool"]["poetry"]["group"] = groups_content["tool"]["poetry"]["group"]
     pyproject = cast("TOMLDocument", pyproject)
     app.poetry.file.write(pyproject)
 
@@ -231,16 +351,26 @@ baz = "^1.0.0"
     pyproject = cast("dict[str, Any]", pyproject)
     content = pyproject["tool"]["poetry"]
     assert "foo" in content["dependencies"]
-    assert "foo" not in content["group"]["bar"]["dependencies"]
-    assert "baz" in content["group"]["bar"]["dependencies"]
 
-    expected = """\
+    if pep_735:
+        assert not any("foo" in dep for dep in pyproject["dependency-groups"]["bar"])
+        assert any("baz" in dep for dep in pyproject["dependency-groups"]["bar"])
+        expected = """\
+[dependency-groups]
+bar = [
+    "baz (>=1.0,<2.0)",
+]
+"""
+    else:
+        assert "foo" not in content["group"]["bar"]["dependencies"]
+        assert "baz" in content["group"]["bar"]["dependencies"]
 
+        expected = """\
 [tool.poetry.group.bar.dependencies]
 baz = "^1.0.0"
-
 """
-    string_content = content.as_string()
+    pyproject = cast("TOMLDocument", pyproject)
+    string_content = pyproject.as_string()
     if "\r\n" in string_content:
         # consistent line endings
         expected = expected.replace("\n", "\r\n")
@@ -248,7 +378,9 @@ baz = "^1.0.0"
     assert expected in string_content
 
 
+@pytest.mark.parametrize("pep_735", [True, False])
 def test_remove_does_not_keep_empty_groups(
+    pep_735: bool,
     tester: CommandTester,
     app: PoetryTestApplication,
     repo: TestRepository,
@@ -261,20 +393,33 @@ def test_remove_does_not_keep_empty_groups(
     repo.add_package(Package("foo", "2.0.0"))
     repo.add_package(Package("baz", "1.0.0"))
 
-    content: dict[str, Any] = app.poetry.file.read()
+    pyproject: dict[str, Any] = app.poetry.file.read()
+    pyproject["tool"]["poetry"]["dependencies"]["foo"] = "^2.0.0"
 
-    groups_content: dict[str, Any] = tomlkit.parse(
-        """\
+    if pep_735:
+        groups_content: dict[str, Any] = tomlkit.parse(
+            """\
+[dependency-groups]
+bar = [
+    "foo (>=2.0,<3.0)",
+    "baz (>=1.0,<2.0)",
+]
+    """
+        )
+        pyproject["dependency-groups"] = groups_content["dependency-groups"]
+    else:
+        groups_content = tomlkit.parse(
+            """\
 [tool.poetry.group.bar.dependencies]
 foo = "^2.0.0"
 baz = "^1.0.0"
 
 """
-    )
-    content["tool"]["poetry"]["dependencies"]["foo"] = "^2.0.0"
-    content["tool"]["poetry"]["group"] = groups_content["tool"]["poetry"]["group"]
-    content = cast("TOMLDocument", content)
-    app.poetry.file.write(content)
+        )
+        groups_content = cast("dict[str, Any]", groups_content)
+        pyproject["tool"]["poetry"]["group"] = groups_content["tool"]["poetry"]["group"]
+    pyproject = cast("TOMLDocument", pyproject)
+    app.poetry.file.write(pyproject)
 
     app.poetry.package.add_dependency(Factory.create_dependency("foo", "^2.0.0"))
     app.poetry.package.add_dependency(
@@ -286,17 +431,26 @@ baz = "^1.0.0"
 
     tester.execute("foo baz --group bar")
 
-    pyproject: dict[str, Any] = app.poetry.file.read()
+    pyproject = app.poetry.file.read()
+    pyproject = cast("dict[str, Any]", pyproject)
     content = pyproject["tool"]["poetry"]
+
     assert "foo" in content["dependencies"]
-    assert "foo" not in content["group"]["bar"]["dependencies"]
-    assert "baz" not in content["group"]["bar"]["dependencies"]
-    content = cast("TOMLDocument", content)
-    assert "[tool.poetry.group.bar]" not in content.as_string()
-    assert "[tool.poetry.group]" not in content.as_string()
+
+    if pep_735:
+        assert "bar" not in pyproject.get("dependency-groups", {})
+        assert "dependency-groups" not in pyproject
+    else:
+        assert "foo" not in content["group"]["bar"]["dependencies"]
+        assert "baz" not in content["group"]["bar"]["dependencies"]
+        content = cast("TOMLDocument", content)
+        assert "[tool.poetry.group.bar]" not in content.as_string()
+        assert "[tool.poetry.group]" not in content.as_string()
 
 
+@pytest.mark.parametrize("pep_735", [True, False])
 def test_remove_canonicalized_named_removes_dependency_correctly(
+    pep_735: bool,
     tester: CommandTester,
     app: PoetryTestApplication,
     repo: TestRepository,
@@ -310,19 +464,32 @@ def test_remove_canonicalized_named_removes_dependency_correctly(
     repo.add_package(Package("baz", "1.0.0"))
 
     pyproject: dict[str, Any] = app.poetry.file.read()
+    pyproject["tool"]["poetry"]["dependencies"]["foo-bar"] = "^2.0.0"
 
-    groups_content: dict[str, Any] = tomlkit.parse(
-        """\
+    if pep_735:
+        groups_content: dict[str, Any] = tomlkit.parse(
+            """\
+[dependency-groups]
+bar = [
+    "foo-bar (>=2.0,<3.0)",
+    "baz (>=1.0,<2.0)",
+]
+"""
+        )
+        pyproject["dependency-groups"] = groups_content["dependency-groups"]
+    else:
+        groups_content = tomlkit.parse(
+            """\
 [tool.poetry.group.bar.dependencies]
 foo-bar = "^2.0.0"
 baz = "^1.0.0"
 
 """
-    )
-    pyproject["tool"]["poetry"]["dependencies"]["foo-bar"] = "^2.0.0"
-    pyproject["tool"]["poetry"].value._insert_after(
-        "dependencies", "group", groups_content["tool"]["poetry"]["group"]
-    )
+        )
+        groups_content = cast("dict[str, Any]", groups_content)
+        pyproject["tool"]["poetry"].value._insert_after(
+            "dependencies", "group", groups_content["tool"]["poetry"]["group"]
+        )
     pyproject = cast("TOMLDocument", pyproject)
     app.poetry.file.write(pyproject)
 
@@ -339,15 +506,25 @@ baz = "^1.0.0"
     pyproject = app.poetry.file.read()
     pyproject = cast("dict[str, Any]", pyproject)
     content = pyproject["tool"]["poetry"]
+
     assert "foo-bar" not in content["dependencies"]
-    assert "foo-bar" not in content["group"]["bar"]["dependencies"]
-    assert "baz" in content["group"]["bar"]["dependencies"]
 
-    expected = """\
+    if pep_735:
+        assert not any("foo" in dep for dep in pyproject["dependency-groups"]["bar"])
+        assert any("baz" in dep for dep in pyproject["dependency-groups"]["bar"])
+        expected = """\
+[dependency-groups]
+bar = [
+    "baz (>=1.0,<2.0)",
+]
+"""
+    else:
+        assert "foo-bar" not in content["group"]["bar"]["dependencies"]
+        assert "baz" in content["group"]["bar"]["dependencies"]
 
+        expected = """\
 [tool.poetry.group.bar.dependencies]
 baz = "^1.0.0"
-
 """
     pyproject = cast("TOMLDocument", pyproject)
     string_content = pyproject.as_string()
