@@ -91,7 +91,10 @@ def test_run_passes_args_after_run_before_command_name_conflict(
     path.rename(path.parent / "run")
 
     app_tester.execute(f"{args} python -V", decorated=True)
-    assert app_tester.io.fetch_error() == ""
+    assert (
+        app_tester.io.remove_format(app_tester.io.fetch_error())
+        == f"Using virtualenv: {env.path}\n"
+    )
     assert env.executed == [["python", "-V"]]
 
 
@@ -200,7 +203,7 @@ def test_run_script_exit_code(
 ) -> None:
     mocker.patch(
         "os.execvpe",
-        lambda file, args, env: subprocess.call([file] + args[1:], env=env),
+        lambda file, args, env: subprocess.call([file, *args[1:]], env=env),
     )
     install_tester = command_tester_factory(
         "install",
@@ -232,7 +235,7 @@ def test_run_script_sys_argv0(
     mocker.patch("poetry.utils.env.EnvManager.get", return_value=tmp_venv)
     mocker.patch(
         "os.execvpe",
-        lambda file, args, env: subprocess.call([file] + args[1:], env=env),
+        lambda file, args, env: subprocess.call([file, *args[1:]], env=env),
     )
 
     install_tester = command_tester_factory(
