@@ -258,7 +258,7 @@ def make_entry_point_from_plugin(
     name: str, cls: type[Any], dist: metadata.Distribution | None = None
 ) -> metadata.EntryPoint:
     group: str | None = getattr(cls, "group", None)
-    ep = metadata.EntryPoint(
+    ep: metadata.EntryPoint = metadata.EntryPoint(
         name=name,
         group=group,  # type: ignore[arg-type]
         value=f"{cls.__module__}:{cls.__name__}",
@@ -277,10 +277,15 @@ def mock_metadata_entry_points(
     name: str = "my-plugin",
     dist: metadata.Distribution | None = None,
 ) -> None:
+    def patched_entry_points(*args: Any, **kwargs: Any) -> list[metadata.EntryPoint]:
+        if "group" in kwargs and kwargs["group"] != getattr(cls, "group", None):
+            return []
+        return [make_entry_point_from_plugin(name, cls, dist)]
+
     mocker.patch.object(
         metadata,
         "entry_points",
-        return_value=[make_entry_point_from_plugin(name, cls, dist)],
+        side_effect=patched_entry_points,
     )
 
 
