@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import os
-import platform
 import shutil
 import zipfile
 
@@ -29,6 +28,7 @@ if TYPE_CHECKING:
     from pytest_mock.plugin import MockerFixture
 
     from poetry.poetry import Poetry
+    from poetry.utils.env.base_env import PythonVersion
     from tests.types import FixtureDirGetter
     from tests.types import ProjectFactory
 
@@ -206,7 +206,7 @@ def test_load_successful_with_invalid_distribution(
 
 
 def test_loads_in_correct_sys_path_order(
-    tmp_path: Path, current_python: tuple[int, int, int], fixture_dir: FixtureDirGetter
+    tmp_path: Path, current_python: PythonVersion, fixture_dir: FixtureDirGetter
 ) -> None:
     path1 = tmp_path / "path1"
     path1.mkdir()
@@ -452,8 +452,6 @@ def test_system_site_packages(
 
     expected_system_site_packages = {"cleo"} if with_system_site_packages else set()
     expected_packages = {"standard"}
-    if platform.system() == "FreeBSD" and not with_system_site_packages:
-        expected_packages.add("sqlite3")
     expected_packages |= expected_system_site_packages
     assert {p.name for p in installed_repository.packages} == expected_packages
     assert {
